
delphin.highlight
=================

.. automodule:: delphin.highlight

   This module contains `Pygments <https://pygments.org/>`_ lexers for
   highlighting SimpleMRS and TDL, as well as a style for coloring MRS
   outputs. This module is primarily intended for use by PyDelphin at
   the command line and in its documentation, but the lexers and style
   can be used directly with Pygments for other purposes.

   Classes
   -------

   .. autoclass:: TDLLexer
   .. autoclass:: SimpleMRSLexer
   .. autoclass:: MRSStyle
